@@ -58,7 +58,7 @@ use namespace::autoclean;
 use version 0.77;
 
 # ABSTRACT: Read annotated source manifest
-our $VERSION = 'v0.4.2_03'; # TRIAL VERSION
+our $VERSION = 'v0.4.2_04'; # TRIAL VERSION
 
 with 'Dist::Zilla::Role::FileGatherer';
 with 'Dist::Zilla::Role::FileFinder';
@@ -151,7 +151,15 @@ sub BUILD {
                 return [ $files->members ];
             },
         } );
-        push( @{ $zilla->plugins }, $finder );
+        # Let's provide old finder names for compatibility:
+        # TODO: Drop it in one or two releases.
+        my $compat = Dist::Zilla::Plugin::FinderCode->new( {
+            plugin_name => do { $_ = $finder->plugin_name; $_ =~ s{/:}{/}x; $_ },
+            zilla       => $finder->zilla,
+            style       => $finder->style,
+            code        => $finder->code,
+        } );
+        push( @{ $zilla->plugins }, $finder, $compat );
     };
     return;
 };
@@ -487,7 +495,7 @@ Dist::Zilla::Plugin::Manifest::Read - Read annotated source manifest
 
 =head1 VERSION
 
-Version v0.4.2_03, released on 2016-11-13 15:04 UTC.
+Version v0.4.2_04, released on 2016-11-17 21:52 UTC.
 This is a B<trial release>.
 
 =head1 WHAT?
